
# Slot: translation of


inverse of translates to

URI: [biolink:translation_of](https://w3id.org/biolink/vocab/translation_of)


## Domain and Range

[Protein](Protein.md) &#8594;  <sub>0..\*</sub> [Transcript](Transcript.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Close Mappings:** | | RO:0002512 |
|  | | SIO:010083 |

